@@ -35,7 +35,6 @@ include("approximation_methods.jl")
 include("retractions.jl")
 include("exp_log_geo.jl")
 include("projections.jl")
-include("metric.jl")
 
 if isdefined(Base, Symbol("@constprop"))
     macro aggressive_constprop(ex)
@@ -51,15 +50,19 @@ end
     allocate(a)
     allocate(a, dims::Integer...)
     allocate(a, dims::Tuple)
+    allocate(a, ::Nothing)
     allocate(a, T::Type)
     allocate(a, T::Type, dims::Integer...)
     allocate(a, T::Type, dims::Tuple)
+    allocate(a, T::Type, ::Nothing)
     allocate(M::AbstractManifold, a)
     allocate(M::AbstractManifold, a, dims::Integer...)
     allocate(M::AbstractManifold, a, dims::Tuple)
+    allocate(M::AbstractManifold, a, ::Nothing)
     allocate(M::AbstractManifold, a, T::Type)
     allocate(M::AbstractManifold, a, T::Type, dims::Integer...)
     allocate(M::AbstractManifold, a, T::Type, dims::Tuple)
+    allocate(M::AbstractManifold, a, T::Type, ::Nothing)
 
 Allocate an object similar to `a`. It is similar to function `similar`, although
 instead of working only on the outermost layer of a nested structure, it maps recursively
@@ -71,26 +74,34 @@ allocation and is forwarded to the function `similar`.
 It's behavior can be overridden by a specific manifold, for example power manifold with
 nested replacing representation can decide that `allocate` for `Array{<:SArray}` returns
 another `Array{<:SArray}` instead of `Array{<:MArray}`, as would be done by default.
+
+If the last argument is `nothing`, it is ignored to support cases where
+`representation_size` is not defined and returns `nothing` but allocation can still go
+off of `a`.
 """
 allocate(a, args...)
 allocate(a) = similar(a)
+allocate(a, ::Nothing) = similar(a)
 allocate(a, dim1::Integer, dims::Integer...) = similar(a, dim1, dims...)
 allocate(a, dims::Tuple) = similar(a, dims)
 allocate(a, T::Type) = similar(a, T)
+allocate(a, T::Type, ::Nothing) = similar(a, T)
 allocate(::Number, T::Type) = fill(zero(T))
 allocate(a, T::Type, dim1::Integer, dims::Integer...) = similar(a, T, dim1, dims...)
 allocate(a, T::Type, dims::Tuple) = similar(a, T, dims)
 allocate(a::AbstractArray{<:AbstractArray}) = map(allocate, a)
 allocate(a::AbstractArray{<:AbstractArray}, T::Type) = map(t -> allocate(t, T), a)
-allocate(a::NTuple{N,AbstractArray} where {N}) = map(allocate, a)
-allocate(a::NTuple{N,AbstractArray} where {N}, T::Type) = map(t -> allocate(t, T), a)
+allocate(a::NTuple{N, AbstractArray} where {N}) = map(allocate, a)
+allocate(a::NTuple{N, AbstractArray} where {N}, T::Type) = map(t -> allocate(t, T), a)
 
 allocate(::AbstractManifold, a) = allocate(a)
+allocate(::AbstractManifold, a, ::Nothing) = allocate(a)
 function allocate(::AbstractManifold, a, dim1::Integer, dims::Integer...)
     return allocate(a, dim1, dims...)
 end
 allocate(::AbstractManifold, a, dims::Tuple) = allocate(a, dims)
 allocate(::AbstractManifold, a, T::Type) = allocate(a, T)
+allocate(::AbstractManifold, a, T::Type, ::Nothing) = allocate(a, T)
 function allocate(::AbstractManifold, a, T::Type, dim1::Integer, dims::Integer...)
     return allocate(a, T, dim1, dims...)
 end
@@ -201,10 +212,8 @@ Return type of element of the array that will represent the result of function `
 [`AbstractManifold`](@ref) `M` on given arguments `args` (passed as a tuple).
 """
 @inline function allocate_result_type(
-    ::AbstractManifold,
-    f::TF,
-    args::NTuple{N,Any},
-) where {N,TF}
+        ::AbstractManifold, f::TF, args::NTuple{N, Any},
+    ) where {N, TF}
     @inline eti_to_one(eti) = one(number_eltype(eti))
     return typeof(sum(map(eti_to_one, args)))
 end
@@ -228,12 +237,8 @@ end
 Check is vectors `X`, `Y` tangent at `p` to `M` are linearly independent.
 """
 function are_linearly_independent(
-    M::AbstractManifold,
-    p,
-    X,
-    Y;
-    atol::Real = sqrt(eps(number_eltype(X))),
-)
+        M::AbstractManifold, p, X, Y; atol::Real = sqrt(eps(number_eltype(X))),
+    )
     norm_X = norm(M, p, X)
     norm_Y = norm(M, p, Y)
     innerXY = inner(M, p, X, Y)
@@ -491,7 +496,13 @@ The default is set in such a way that memory is allocated and `embed!(M, q, p)`
 See also: [`EmbeddedManifold`](@ref), [`project`](@ref project(M::AbstractManifold,p))
 """
 function embed(M::AbstractManifold, p)
-    q = allocate_result(M, embed, p)
+    local q
+    try
+        q = allocate_result_embedding(M, embed, p)
+    catch e
+        # because we want `embed` to default to identity
+        q = allocate_result(M, embed, p)
+    end
     embed!(M, q, p)
     return q
 end
@@ -539,7 +550,13 @@ See also: [`EmbeddedManifold`](@ref), [`project`](@ref project(M::AbstractManifo
 """
 function embed(M::AbstractManifold, p, X)
     # the order of args switched, since the allocation by default takes the type of the first.
-    Y = allocate_result(M, embed, X, p)
+    local Y
+    try
+        Y = allocate_result_embedding(M, embed, X, p)
+    catch e
+        # because we want `embed` to default to identity
+        Y = allocate_result(M, embed, X, p)
+    end
     embed!(M, Y, p, X)
     return Y
 end
@@ -587,13 +604,42 @@ function embed_project(M::AbstractManifold, p, X)
     return project(M, p, embed(M, p, X))
 end
 
+"""
+    embed_project!(M::AbstractManifold, q, p)
+
+Embed `p` from manifold `M` an project it back to `M`, saving the result in `q`. For points
+from `M` this is identity but in case embedding is defined for points outside of `M`, this
+can serve as a way to for example remove numerical inaccuracies caused by some algorithms.
+"""
 function embed_project!(M::AbstractManifold, q, p)
     return project!(M, q, embed(M, p))
 end
+
+"""
+    embed_project!(M::AbstractManifold, Y, p, X)
+
+Embed vector `X` tangent at `p` from manifold `M` an project it back to tangent space
+at `p`, saving the result in `Y`. For points from that tangent space this is identity but
+in case embedding is defined for tangent vectors from outside of it, this can serve as a way
+to for example remove numerical inaccuracies caused by some algorithms.
+"""
 function embed_project!(M::AbstractManifold, Y, p, X)
     return project!(M, Y, p, embed(M, p, X))
 end
 
+_doc_embedding = """
+    get_embedding(M::AbstractManifold)
+    get_embedding(M::AbstractManifold, ::Type)
+
+Return the embedding [`AbstractManifold`](@ref) of `M`, if it exists.
+The embedding might depend on the type  ``P`` points are represented with.
+The default is, that the signature with the type defaults to the one without.
+"""
+@doc "$(_doc_embedding)"
+get_embedding(M::AbstractManifold, ::Type) = get_embedding(M)
+@doc "$(_doc_embedding)"
+get_embedding(M::AbstractManifold)
+
 """
     has_components(M::AbstractManifold)
 
@@ -652,7 +698,18 @@ injectivity_radius_exp(M::AbstractManifold) = injectivity_radius(M)
     inner(M::AbstractManifold, p, X, Y)
 
 Compute the inner product of tangent vectors `X` and `Y` at point `p` from the
-[`AbstractManifold`](@ref) `M`.
+[`AbstractManifold`](@ref) `M`. The result type varies by the exact type of `M`:
+
+1. On a [Riemannian manifold](https://en.wikipedia.org/wiki/Riemannian_manifold)
+   the result is a real number.
+2. On an [almost complex manifold](https://en.wikipedia.org/wiki/Almost_complex_manifold)
+   the result is a complex number.
+3. On an [almost quaternionic manifold](https://en.wikipedia.org/wiki/Quaternionic_manifold#Almost_quaternionic_structure)
+   the result is a quaternion.
+4. On a [CR manifold](https://en.wikipedia.org/wiki/CR_manifold) the result may be either
+   real or complex, depending on the particular manifold.
+
+In cases 2, 3 and 4 the Riemannian inner product can be obtained by taking the real part.
 """
 inner(M::AbstractManifold, p, X, Y)
 
@@ -682,7 +739,7 @@ Currently the following are supported
 Keyword arguments can be used to specify tolerances.
 """
 function isapprox(M::AbstractManifold, p, q; error::Symbol = :none, kwargs...)
-    if error === :none
+    if error === :none  # Shortcut to avoid error message allocation
         return _isapprox(M, p, q; kwargs...)
     else
         ma = check_approx(M, p, q; kwargs...)
@@ -716,12 +773,12 @@ Currently the following are supported
 * `:warn` – prints the information in an `@warn`
 * `:none` (default) – the function just returns `true`/`false`
 
-By default these informations are collected by calling [`check_approx`](@ref).
+By default these pieces of information are collected by calling [`check_approx`](@ref).
 
 Keyword arguments can be used to specify tolerances.
 """
 function isapprox(M::AbstractManifold, p, X, Y; error::Symbol = :none, kwargs...)
-    if error === :none
+    if error === :none # Shortcut to avoid error message allocation
         return _isapprox(M, p, X, Y; kwargs...)::Bool
     else
         mat = check_approx(M, p, X, Y; kwargs...)
@@ -784,12 +841,12 @@ The second signature is a shorthand, where the boolean is used for `error=:error
 and `error=:none` (default, `false`). This case ignores the `error=` keyword
 """
 function is_point(
-    M::AbstractManifold,
-    p,
-    throw_error::Bool;
-    error::Symbol = :none,
-    kwargs...,
-)
+        M::AbstractManifold,
+        p,
+        throw_error::Bool;
+        error::Symbol = :none,
+        kwargs...,
+    )
     return is_point(M, p; error = throw_error ? :error : :none, kwargs...)
 end
 function is_point(M::AbstractManifold, p; error::Symbol = :none, kwargs...)
@@ -848,31 +905,18 @@ The second signature is a shorthand, where `throw_error` is used for `error=:err
 and `error=:none` (default, `false`). This case ignores the `error=` keyword.
 """
 function is_vector(
-    M::AbstractManifold,
-    p,
-    X,
-    check_base_point::Bool,
-    throw_error::Bool;
-    error::Symbol = :none,
-    kwargs...,
-)
+        M::AbstractManifold, p, X, check_base_point::Bool, throw_error::Bool;
+        error::Symbol = :none, kwargs...,
+    )
     return is_vector(
-        M,
-        p,
-        X,
-        check_base_point;
-        error = throw_error ? :error : :none,
-        kwargs...,
+        M, p, X, check_base_point;
+        error = throw_error ? :error : :none, kwargs...,
     )
 end
 function is_vector(
-    M::AbstractManifold,
-    p,
-    X,
-    check_base_point::Bool = true;
-    error::Symbol = :none,
-    kwargs...,
-)
+        M::AbstractManifold, p, X, check_base_point::Bool = true;
+        error::Symbol = :none, kwargs...,
+    )
     if check_base_point
         # if error, is_point throws, otherwise if not a point return false
         !is_point(M, p; error = error, kwargs...) && return false
@@ -955,11 +999,11 @@ number_eltype(x) = eltype(x)
 @inline function number_eltype(x::AbstractArray)
     return typeof(mapreduce(eti -> one(number_eltype(eti)), +, x))
 end
-@inline number_eltype(::AbstractArray{T}) where {T<:Number} = T
+@inline number_eltype(::AbstractArray{T}) where {T <: Number} = T
 @inline function number_eltype(::Type{<:AbstractArray{T}}) where {T}
     return number_eltype(T)
 end
-@inline function number_eltype(::Type{<:AbstractArray{T}}) where {T<:Number}
+@inline function number_eltype(::Type{<:AbstractArray{T}}) where {T <: Number}
     return T
 end
 @inline function number_eltype(x::Tuple)
@@ -1014,12 +1058,22 @@ function Random.rand(rng::AbstractRNG, M::AbstractManifold; vector_at = nothing,
     return pX
 end
 
+function Random.rand!(M::AbstractManifold, pX; kwargs...)
+    return rand!(Random.default_rng(), M, pX; kwargs...)
+end
+
+
 @doc raw"""
     representation_size(M::AbstractManifold)
 
-The size of an array representing a point on [`AbstractManifold`](@ref) `M`.
-Returns `nothing` by default indicating that points are not represented using an
-`AbstractArray`.
+Return the size of an array representing a point or a tangent vector on a
+certain [`AbstractManifold`](@ref) `M`.
+This is either the size of the `AbstractArray` representing points or tangent vectors on `M`
+or what a `size(p)` would return for the case of points and tangent vectors that are
+subtypes of [`AbstractManifoldPoint`](@ref) or [`AbstractTangentVector`](@ref), respectively.
+
+By default this function returns `nothing` indicating that the representation on
+`M` can not be done in (plain, wrapped) arrays, for example because it is a number of a collection of arrays.
 """
 function representation_size(::AbstractManifold)
     return nothing
@@ -1094,7 +1148,8 @@ sectional_curvature_min(M::AbstractManifold)
 
 Converts a size given by `Tuple{N, M, ...}` into a tuple `(N, M, ...)`.
 """
-Base.@pure size_to_tuple(::Type{S}) where {S<:Tuple} = tuple(S.parameters...)
+Base.@pure size_to_tuple(::Type{S}) where {S <: Tuple} = tuple(S.parameters...) # COV_EXCL_LINE
+# the line above is excluded from coverage, since codecov has sometimes troubles with macros.
 
 """
     tangent_vector_type(::AbstractManifold, point_type::Type)
@@ -1165,6 +1220,10 @@ include("shooting.jl")
 include("vector_spaces.jl")
 include("point_vector_fallbacks.jl")
 include("nested_trait.jl")
+
+include("connection.jl")
+include("metric.jl")
+
 include("decorator_trait.jl")
 include("numerical_checks.jl")
 
@@ -1175,6 +1234,7 @@ include("EmbeddedManifold.jl")
 include("DefaultManifold.jl")
 include("ProductManifold.jl")
 include("PowerManifold.jl")
+include("quotientmanifold.jl")
 
 include("deprecated.jl")
 #
@@ -1185,7 +1245,7 @@ function __init__()
     #
     # Error Hints
     #
-    @static if isdefined(Base.Experimental, :register_error_hint) # COV_EXCL_LINE
+    return @static if isdefined(Base.Experimental, :register_error_hint) # COV_EXCL_LINE
         Base.Experimental.register_error_hint(MethodError) do io, exc, argtypes, kwargs
             if exc.f === plot_slope
                 print(
@@ -1226,12 +1286,14 @@ export AbstractManifold,
     AbstractCotangentVector,
     TFVector,
     CoTFVector
+export AbstractAffineConnection, ConnectionManifold, LeviCivitaConnection
+export AbstractMetric, MetricManifold
 export VectorSpaceFiber
 export TangentSpace, TangentSpaceType
 export CotangentSpace, CotangentSpaceType
 export AbstractDecoratorManifold
-export AbstractTrait, IsEmbeddedManifold, IsEmbeddedSubmanifold, IsIsometricEmbeddedManifold
-export IsExplicitDecorator
+export AbstractForwardingType, StopForwardingType, SimpleForwardingType
+export AbstractEmbeddedForwardingType, EmbeddedForwardingType
 export ValidationManifold,
     ValidationMPoint, ValidationTangentVector, ValidationCotangentVector
 export EmbeddedManifold
@@ -1253,12 +1315,12 @@ export GeodesicInterpolationWithinRadius,
 
 # (b) Retraction Types
 export AbstractRetractionMethod,
-    ApproximateInverseRetraction,
+    ApproximateRetraction,
+    ApproximateExponentialRetraction,
     CayleyRetraction,
     EmbeddedRetraction,
     ExponentialRetraction,
     NLSolveInverseRetraction,
-    ODEExponentialRetraction,
     QRRetraction,
     PadeRetraction,
     PolarRetraction,
@@ -1273,6 +1335,7 @@ export AbstractRetractionMethod,
 # (c) Inverse Retraction Types
 export AbstractInverseRetractionMethod,
     ApproximateInverseRetraction,
+    ApproximateLogarithmicInverseRetraction,
     CayleyInverseRetraction,
     EmbeddedInverseRetraction,
     InverseProductRetraction,
@@ -1283,7 +1346,8 @@ export AbstractInverseRetractionMethod,
     PolarInverseRetraction,
     ProjectionInverseRetraction,
     InverseRetractionWithKeywords,
-    SoftmaxInverseRetraction
+    SoftmaxInverseRetraction,
+    StabilizedInverseRetraction
 
 # (d) Vector Transport Types
 export AbstractVectorTransportMethod,
@@ -1324,12 +1388,15 @@ export ×,
     angle,
     base_manifold,
     base_point,
+    canonical_project,
+    canonical_project!,
     change_basis,
     change_basis!,
     change_metric,
     change_metric!,
     change_representer,
     change_representer!,
+    check_geodesic,
     check_inverse_retraction,
     check_retraction,
     check_vector_transport,
@@ -1341,6 +1408,8 @@ export ×,
     default_retraction_method,
     default_type,
     default_vector_transport_method,
+    diff_canonical_project,
+    diff_canonical_project!,
     distance,
     exp,
     exp!,
@@ -1357,12 +1426,18 @@ export ×,
     get_coordinates,
     get_coordinates!,
     get_embedding,
+    get_embedding_type,
+    get_total_space,
     get_vector,
     get_vector!,
     get_vectors,
     has_components,
     hat,
     hat!,
+    horizontal_component,
+    horizontal_component!,
+    horizontal_lift,
+    horizontal_lift!,
     injectivity_radius,
     inner,
     internal_value,
@@ -1412,6 +1487,8 @@ export ×,
     vector_transport_to!,
     vee,
     vee!,
+    vertical_component,
+    vertical_component!,
     Weingarten,
     Weingarten!,
     zero_vector,
