@@ -1,88 +1,24 @@
 using Test
 using ManifoldsBase
 
-using ManifoldsBase: AbstractTrait, TraitList, EmptyTrait, trait, merge_traits
-using ManifoldsBase: expand_trait, next_trait
-import ManifoldsBase: active_traits, parent_trait
-
-struct IsCool <: AbstractTrait end
-struct IsNice <: AbstractTrait end
-
-abstract type AbstractA end
-abstract type DecoA <: AbstractA end
-# A few concrete types
-struct A <: AbstractA end
-struct A1 <: DecoA end
-struct A2 <: DecoA end
-struct A3 <: DecoA end
-struct A4 <: DecoA end
-struct A5 <: DecoA end
-
-# just some function
-f(::AbstractA, x) = x + 2
-g(::DecoA, x, y) = x + y
-
-struct IsGreat <: AbstractTrait end # a special case of IsNice
-parent_trait(::IsGreat) = IsNice()
-
-active_traits(f, ::A1, ::Any) = merge_traits(IsNice())
-active_traits(f, ::A2, ::Any) = merge_traits(IsCool())
-active_traits(f, ::A3, ::Any) = merge_traits(IsCool(), IsNice())
-active_traits(f, ::A5, ::Any) = merge_traits(IsGreat())
-
-f(a::DecoA, b) = f(trait(f, a, b), a, b)
-
-f(::TraitList{IsNice}, a, b) = g(a, b, 3)
-f(::TraitList{IsCool}, a, b) = g(a, b, 5)
-
-# generic forward to the next trait to be looked at
-f(t::TraitList, a, b) = f(next_trait(t), a, b)
-# generic fallback when no traits are defined
-f(::EmptyTrait, a, b) = invoke(f, Tuple{AbstractA,typeof(b)}, a, b)
-
-@testset "Decorator trait tests" begin
-    t = ManifoldsBase.EmptyTrait()
-    t2 = ManifoldsBase.TraitList(t, t)
-    @test merge_traits() == t
-    @test merge_traits(t) == t
-    @test merge_traits(t, t) == t
-    @test merge_traits(t2) == t2
-    @test merge_traits(
-        merge_traits(IsGreat(), IsNice()),
-        merge_traits(IsGreat(), IsNice()),
-    ) === merge_traits(IsGreat(), IsNice(), IsGreat(), IsNice())
-    @test expand_trait(merge_traits(IsGreat(), IsCool())) ===
-          merge_traits(IsGreat(), IsNice(), IsCool())
-    @test expand_trait(merge_traits(IsCool(), IsGreat())) ===
-          merge_traits(IsCool(), IsGreat(), IsNice())
-
-    @test string(merge_traits(IsGreat(), IsNice())) ==
-          "TraitList(IsGreat(), TraitList(IsNice(), EmptyTrait()))"
-
-    global f
-    @test f(A(), 0) == 2
-    @test f(A2(), 0) == 5
-    @test f(A3(), 0) == 5
-    @test f(A4(), 0) == 2
-    @test f(A5(), 890) == 893
-    f(::TraitList{IsGreat}, a, b) = g(a, b, 54)
-    @test f(A5(), 890) == 944
-
-    @test next_trait(EmptyTrait()) === EmptyTrait()
-end
+s = @__DIR__
+!(s in LOAD_PATH) && (push!(LOAD_PATH, s))
+using ManifoldsBaseTestUtils
 
 #
-# A Manifold decorator test - check that EmptyTrait cases call Abstract and those fail with
+# A Manifold decorator test - check that StopForwarding cases call Abstract and those fail with
 # MethodError due to ambiguities (between Abstract and Decorator)
 struct NonDecoratorManifold <: AbstractDecoratorManifold{ManifoldsBase.ℝ} end
 ManifoldsBase.representation_size(::NonDecoratorManifold) = (2,)
 
-@testset "Testing a NonDecoratorManifold - emptytrait fallbacks" begin
+@testset "Testing a NonDecoratorManifold - StopForwarding fallbacks" begin
     M = NonDecoratorManifold()
     p = [2.0, 1.0]
     q = similar(p)
     X = [1.0, 0.0]
+    Xc = [1.0, 0.0]
     Y = similar(X)
+    Yc = similar(Xc)
     @test ManifoldsBase.check_size(M, p) === nothing
     @test ManifoldsBase.check_size(M, p, X) === nothing
     # default to identity
@@ -122,15 +58,41 @@ ManifoldsBase.representation_size(::NonDecoratorManifold) = (2,)
     @test_throws MethodError parallel_transport_direction!(M, Y, p, X, X)
     @test_throws MethodError parallel_transport_to(M, p, X, q)
     @test_throws MethodError parallel_transport_to!(M, Y, p, X, q)
+    @test_throws MethodError get_vector(M, p, Xc)
+    @test_throws MethodError get_vector(M, p, Xc, DefaultOrthogonalBasis())
+    @test_throws MethodError get_coordinates!(M, Yc, p, X)
+    @test_throws MethodError get_vector!(M, Y, p, Xc)
+    @test_throws MethodError get_coordinates!(M, Yc, p, X, DefaultOrthogonalBasis())
+    @test_throws MethodError get_vector!(M, Y, p, Xc, DefaultOrthogonalBasis())
+
+    @test_throws MethodError project(M, p)
+    @test_throws MethodError project(M, p, X)
+    @test_throws MethodError project!(M, q, p)
+    @test_throws MethodError project!(M, Y, p, X)
 end
 
 # With even less, check that representation size stack overflows
 struct NonDecoratorNonManifold <: AbstractDecoratorManifold{ManifoldsBase.ℝ} end
-@testset "Testing a NonDecoratorNonManifold - emptytrait fallback Errors" begin
+@testset "Testing a NonDecoratorNonManifold - StopForwarding fallback returns nothing" begin
     N = NonDecoratorNonManifold()
-    @test_throws StackOverflowError representation_size(N)
+    @test representation_size(N) === nothing
 end
 
+@testset "Non-decorator manifold trait defaults" begin
+    M = ProjManifold()
+    p = [
+        sqrt(2) / 2 0.0 0.0
+        0.0 sqrt(2) / 2 0.0
+    ]
+
+    @test ManifoldsBase.get_forwarding_type(M, exp) === StopForwardingType()
+    @test ManifoldsBase.get_forwarding_type(M, exp, typeof(p)) === StopForwardingType()
+end
+
+abstract type AbstractA end
+abstract type DecoA <: AbstractA end # A few concrete types
+struct A <: AbstractA end
+struct A1 <: DecoA end
 
 h(::AbstractA, x::Float64, y; a = 1) = x + y - a
 h(::DecoA, x, y) = x + y
